@@ -339,7 +339,10 @@ def vp_matcher(doc): #[('vend', 'consider going', 1, 3), ('vp', 'consider going'
 	if not hasattr(vp_matcher, 'matcher'): 
 		vp_matcher.matcher = Matcher(spacy.nlp.vocab)
 		[vp_matcher.matcher.add(name, patterns,  greedy ='LONGEST') for name, patterns in _vp_rules.items() ]
-	return [(spacy.nlp.vocab[name].text, vp_span(doc,ibeg,iend), ibeg, iend) for name, ibeg,iend in vp_matcher.matcher(doc)] 
+	#return [(spacy.nlp.vocab[name].text, vp_span(doc,ibeg,iend), ibeg, iend) for name, ibeg,iend in vp_matcher.matcher(doc)] 
+	tups = set()  # remove the duplicated entries 
+	[tups.add((spacy.nlp.vocab[name].text, vp_span(doc,ibeg,iend), ibeg, iend)) for name, ibeg,iend in vp_matcher.matcher(doc)] 
+	return tups
 
 _dep_rules = {
 "svo":[ 
@@ -593,8 +596,8 @@ def dep_matcher(doc): #[('svx', [1, 0, 2])]
 
 [setattr(builtins, k, v) for k, v in globals().items() if not k.startswith("_") and not '.' in k and not hasattr(builtins,k) ] #setattr(builtins, "spacy", spacy)			
 if __name__	== '__main__': 
-	doc = spacy.nlp("I consider going to there.") 
-	print ( dep_matcher(doc) ) 
+	doc = spacy.nlp("It is on the brink, and I am very happy.") 
+	print ( vp_matcher(doc) ) 
 	#print(sntbr("[\u8bd1\u6587]The 55-kilometre Hong Kong Zhuhai-Macau Bridge is an extraordinary engineering. It is the world's longest sea-crossing transportation system combining bridges and tunnels, which joins the three cities of Hong Kong Zhuhai and Macao, cutting the travelling time among them from 3 hours to 30 minutes. The reinforced concrete bridge with huge spans fully not only proves that China has the ability to complete the record-breaking mega-construction, but also will enhance the regional integration and boost the economic growth. It plays a crucial role in the overall plan to develop China’s Great Bay Area, which China intends to turn into one rivaling those of San Francisco, New York and Tokyo in terms of technological innovation and economic prosperity.", with_pid=True))
 #c:\users\zhang\appdata\local\programs\python\python38\lib\site-packages  
 #/home/ubuntu/.local/lib/python3.8/site-packages/en
\ No newline at end of file
