@@ -18,8 +18,9 @@ def walk(doc):
 	for sp in doc.noun_chunks: #book:NOUN:np:a book
 		add(f"{sp.root.lemma_.lower()}:{sp.root.pos_}:np:{sp.text.lower()}", f"{sp.root.lemma_.lower()}:{sp.root.pos_}:np", f"#np",)
 
-	for type, chunk, start, end in en.vp_matcher(doc): #[('vend', 'consider going', 1, 3)
-		add(f"{doc[start].lemma_}:{doc[start].pos_}:{type}:{chunk}") #consider:VERB:vtov:consider to go
+	# [('pp', 'on the brink', 2, 5), ('ap', 'very happy', 9, 11)]
+	for type, chunk, start, end in en.vp_matcher(doc): #[('vend', 'consider going', 1, 3) #consider:VERB:vtov:consider to go
+		add(f"{doc[start].lemma_}:{doc[start].pos_}:{type}:{chunk}", f"{doc[start].lemma_}:{doc[start].pos_}:{type}") if type.startswith("v") else add(f"{doc[end-1].lemma_}:{doc[end-1].pos_}:{type}:{chunk}", f"{doc[end-1].lemma_}:{doc[end-1].pos_}:{type}" ) 
 
 	for trpx, row in en.dep_matcher(doc): #[('svx', [1, 0, 2])]
 		verbi = row[0]
@@ -29,7 +30,8 @@ def walk(doc):
 	for row in en.verbnet_matcher(doc): #[(1, 0, 3, 'NP V S_ING')]
 		if len(row) == 4: 
 			verbi, ibeg, iend, chunk = row
-			add(f"{doc[verbi].lemma_}:{doc[verbi].pos_}:verbnet:{chunk}") #consider:VERB:verbnet:NP V S_ING
+			if doc[verbi].lemma_.isalpha() : 
+				add(f"{doc[verbi].lemma_}:{doc[verbi].pos_}:verbnet:{chunk}") #consider:VERB:verbnet:NP V S_ING
 
 def mysql(dbfile, host='127.0.0.1', port=3307):  
 	''' clec.spacybs -> mysql:kpsi/clec,clec_snt , 2022.7.4 '''
@@ -53,7 +55,6 @@ def mysql(dbfile, host='127.0.0.1', port=3307):
 				print ("ex:", e, rowid, snt)
 				exc_type, exc_value, exc_traceback_obj = sys.exc_info()
 				traceback.print_tb(exc_traceback_obj)
-				break
 
 		cursor.executemany(f"insert ignore into {name}(s, i) values(%s, %s)",[(k,v) for k,v in fire.si.items()]) #cursor.executemany(f"INSERT INTO {name}(s,i) VALUES (%s, %s) ON DUPLICATE KEY UPDATE i = i + %s", [(k,v,v) for k,v in fire.si.items()] )
 		my_conn.commit()
