@@ -1,6 +1,6 @@
 # 2022.5.11 updated , add sqlrow for EachRowJson
 # 2022.2.13 created 
-import requests,json, os, math,re,traceback
+import requests,json, os, math,re,traceback,fire,time
 from elasticsearch import Elasticsearch,helpers
 from collections import	defaultdict, Counter
 import pandas as pd 
@@ -249,6 +249,47 @@ def sqlrow(query="select lem, count(*) cnt  from gzjc where type = 'tok' and pos
 	columns = [ ar['name'] for ar in res['columns'] ]
 	return  [  dict(zip(columns, ar)) for ar in res['rows'] ] #[{'lem': 'the', 'cnt': 7552}, {'lem': 'be', 'cnt': 5640}, {'lem': 'and', 'cnt': 3604}, {'lem': 'to', 'cnt': 3561}, {'lem': 'of', 'cnt': 3127}, {'lem': 'a', 'cnt': 2902}, {'lem': 'in', 'cnt': 2687}, {'lem': 'I', 'cnt': 2063}, {'lem': 'have', 'cnt': 1562}, {'lem': 'it', 'cnt': 1311}]
 
+## added 2022.7.3
+requests.esname = os.getenv("esname", "es.corpusly.com:9200")
+cursor_sql = lambda query, cursor: requests.post(f"http://{requests.esname}/_sql", json={"query":query, "cursor":cursor}).json() 
+
+def cursor_rows(query="select dep, gov, lem, pos, count(*) cnt from gzjc where type='tok' group by dep, gov, lem, pos"):
+	rows = []				
+	cursor=''
+	while True : 
+		res = cursor_sql(query, cursor)  
+		rows.extend(res['rows'])
+		cursor = res.get('cursor','') 
+		if not cursor: break
+	return rows 
+
+def sqlsi(query): #select lex, count(*)
+	si = Counter()
+	cursor=''
+	while True : 
+		res = cursor_sql(query, cursor)  
+		si.update( dict(res['rows']) )
+		cursor = res.get('cursor','') 
+		if not cursor: break
+	return si #dict(si.most_common())
+
+def sqlssi(query="select lem, lex, count(*) cnt from gzjc where type = 'tok' and lem rlike '[a-z]+' group by lem, lex"
+		, iftrue = lambda s1, s2: s1 and s2
+		, s1_func = lambda s: s
+		, s2_func = lambda s: s  # lower()
+		): 
+	ssi = defaultdict(Counter)
+	cursor=''
+	while True : 
+		res = cursor_sql(query, cursor) 
+		[ ssi[ s1_func(s1) ].update({ s2_func(s2) :cnt}) for s1, s2, cnt in res['rows'] if iftrue(s1, s2) ] 
+		cursor = res.get('cursor','') 
+		if not cursor: break
+	return ssi 
+
+trpssi	= lambda idxname, dep='dobj', gpos='VERB', dpos='NOUN': sqlssi(f"select gov, lem, count(*) cnt from {idxname} where type = 'tok' and pos = '{dpos}' and dep ='{dep}' and lem rlike '[a-z]+' and gov like '%_{gpos}' group by gov, lem", s1_func =lambda s: s.split('_')[0])
+_trpssi = lambda idxname, dep='dobj', gpos='VERB', dpos='NOUN': sqlssi(f"select lem, gov, count(*) cnt from {idxname} where type = 'tok' and pos = '{dpos}' and dep ='{dep}' and lem rlike '[a-z]+' and gov like '%_{gpos}' group by lem, gov", s2_func =lambda s: s.split('_')[0])
+
 def readline(infile, sepa=None):
 	with open(infile, 'r') as fp:
 		while True:
