@@ -53,7 +53,7 @@ def load(infile, host = '172.17.0.1',port=6379,  db=0, password=None):
 			print ("ex:", e, "\t|",  line) 
 	print ("finished loading:", infile, r)
 
-def delkeys(pattern, host = 'localhost',port=6379,  db=0):
+def delkeys(pattern, host = '172.17.0.1',port=6379,  db=0):
 	''' delete keys by pattern '''
 	r = redis.Redis(host=host, port=port, db=db, decode_responses=True)
 	print (r, pattern , flush=True)
