@@ -4,10 +4,16 @@ import re
 requests.eshp	= os.getenv("eshp", "es.corpusly.com:9200") # host & port 
 
 @app.get('/es/rows', tags=["es"])
-def rows(query="select lem, count(*) cnt  from gzjc where type = 'tok' and pos != 'PUNCT' group by lem order by cnt desc limit 10", raw:bool=False):
-	''' # select snt from dic where type = 'snt' and kp = 'book_VERB' limit 2 '''
+def rows(query="select lem, count(*) cnt  from gzjc where type = 'tok' and pos != 'PUNCT' group by lem order by cnt desc limit 10", raw:bool=False, sum_query:str=None):
+	''' # select snt from dic where type = 'snt' and kp = 'book_VERB' limit 2 
+	# sum_query: select count(*) from gzjc where type='tok' '''
 	res = requests.post(f"http://{requests.eshp}/_sql",json={"query": query}).json() 
-	return res['rows'] if raw else  [  dict(zip([ ar['name'] for ar in res['columns'] ] , ar)) for ar in res.get('rows',[]) ] 
+	if raw: return res['rows']  
+	if not sum_query is None: 
+		sumi = requests.post(f"http://{requests.eshp}/_sql",json={"query": sum_query}).json()['rows'][0][0]
+		return [  dict( dict(zip([ ar['name'] for ar in res['columns'] ] , ar)), **{"sumi":sumi}) for ar in res.get('rows',[]) ] 
+	return [  dict(zip([ ar['name'] for ar in res['columns'] ] , ar)) for ar in res.get('rows',[]) ] 
+	#return res['rows'] if raw else  [  dict(zip([ ar['name'] for ar in res['columns'] ] , ar)) for ar in res.get('rows',[]) ] 
 
 @app.get('/es/count', tags=["es"])
 def rows_count(cp:str='gzjc', type:str='snt'):
@@ -44,7 +50,7 @@ def corpus_stats(names:str=None, types:str="doc,snt,np,tok,trp,vp"):
 	return [ dict( dict(rows(f"select type, count(*) cnt from {name} where type in ('{types}') group by type")), **{"name":name} ) for name in names]
 
 if __name__ == "__main__":   #uvicorn.run(app, host='0.0.0.0', port=80)
-	print ( es_outer_join() )
+	print ( rows(sum_query="select count(*) from gzjc where type='tok'") )
 	#uvicorn.run(app, host='0.0.0.0', port=80)
 
 '''
