@@ -4,26 +4,61 @@ import spacy
 if not hasattr(spacy, 'nlp'): spacy.nlp  = spacy.load('en_core_web_sm')
 
 @app.get('/spacy/tok', tags=["spacy"])
-def spacy_tok(text:str='The boy is happy. The quick fox jumped over the lazy dog.',chunks:bool=False): 
+def spacy_tok(text:str='The quick fox jumped over the lazy dog.',chunks:bool=False, morph:bool=False): 
 	''' select * from url('http://cpu76.wrask.com:8000/spacy/tok', JSONEachRow, 'i UInt32, head UInt32, off UInt32, lex String, text_with_ws String,lem String, pos String, tag String, dep String, gov String') ''' 
 	doc = spacy.nlp(text) 
 	dic = { t.i: {'i':t.i, "head":t.head.i, 'off':t.idx, 'lex':t.text, 'text_with_ws':t.text_with_ws, 'lem':t.lemma_, 'pos':t.pos_, 'tag':t.tag_, 'dep':t.dep_, "gov":t.head.lemma_ + "_" + t.head.pos_ }  for t in doc }
+	if morph: [v.update({"morph":json.dumps(doc[i].morph.to_dict())}) for i,v in dic.items()]
 	if chunks: 
 		[v.update({"chunks":[]}) for k,v in dic.items()]
 		[ dic[ sp.end - 1 ]['chunks'].append( {'lempos': doc[sp.end - 1].lemma_ + "_NOUN", "type":"NP", "chunk":sp.text.lower() } ) for sp in doc.noun_chunks]   ## start/end ? 
 	return [ v for v in dic.values()]  # colored VERB html
 
+@app.get('/spacy/chunks', tags=["spacy"])
+def spacy_chunks(text:str='The quick fox jumped over the lazy dog.'): 
+	''' add vp_matcher,  the fox:NP-DET NOUN ''' 
+	doc = spacy.nlp(text) 
+	return [{"chunk":sp.text.lower() +":NP-" + " ".join([ doc[i].pos_ for i in range(sp.start, sp.end)])} for sp in doc.noun_chunks if sp.end - sp.start > 1] 
+
 @app.get('/spacy/trp', tags=["spacy"])
 def spacy_trp(text:str='The boy is happy. The quick fox jumped over the lazy dog.'): 
 	''' select * from url('http://cpu76.wrask.com:8000/spacy/trp', JSONEachRow, 'rel String, gov String, dep String') ''' 
 	return [{'rel':f"{t.dep_}_{t.head.pos_}_{t.pos_}", "gov":t.head.lemma_, 'dep':t.lemma_}  for t in spacy.nlp(text)  ]
 
+@app.get('/spacy/snt', tags=["spacy"])
+def spacy_snt(text:str='I think I plan to go swimming.', funcs:str="vp,verbnet,clause"): 
+	''' select * from url('http://cpu76.wrask.com:8000/spacy/snt?text=I%20think%20I%20plan%20to%20go%20swimming.&func=vp%2Cverbnet%2Cclause', LineAsString )  ''' 
+	import en 
+	mapf = { 
+	"clause":	lambda doc	: [ {"verb":v.lemma_, "type":type, "start":start, "end":end, "chunk":chunk } for v,type, start, end, chunk in en.clause(doc)],
+	"verbnet":	lambda doc	: [ {"verb":doc[verb_i].lemma_,  "start":start, "end":end, "chunk":chunk } for verb_i, start, end, chunk in en.verbnet_matcher(doc)],
+	"vp":	lambda doc		: [ {"verb":doc[start].lemma_,  "start":start, "end":end, "chunk":chunk } for vp, chunk, start, end in en.vp_matcher(doc)],
+	}
+	doc = spacy.nlp(text)
+	return { f: mapf.get(f, lambda doc: [])(doc)  for f in funcs.strip().split(',') }
+
+@app.get('/spacy/meta', tags=["spacy"])
+def doc_meta(text:str='She is happy.'): 
+	''' {"pred":"jumped", "sub": "fox", "obj":"dog" } ''' 
+	try:
+		doc		= spacy.nlp(text) 
+		predi	= [ t.i for t in doc if t.dep_ == 'ROOT'][0]
+		meta	= {	t.dep_: t.text	for t in doc if t.dep_ not in ('punct') and t.head.i == predi } #if t.dep_ in ('nsubj','dobj','acomp') and t.head.i == predi:  meta[t.dep_] = t.text 
+		return meta
+	except Exception as e:
+		print("ex:", e) 
+
 @app.get('/spacy/highlight', tags=["spacy"])
-def doc_highlight(text:str='The boy is happy. The quick fox jumped over the lazy dog.', pos:str='ADJ'):
+def doc_highlight(text:str='The quick fox jumped over the lazy dog.'): #, pos:str='ADJ'
 	''' return html, with pos highlighted ''' 
 	doc = spacy.nlp(text) 
-	arr = [ ("<b>" if t.pos_ == pos else "") + t.text_with_ws + ("</b>" if t.pos_ == pos else "") for t in doc]
-	return "".join(arr) 
+	color = {'ROOT': 'red'}
+	dic = { t.i:  f"<span class='{t.pos_}' style='color:{color.get(t.dep_, 'black')}'>{t.text_with_ws}</span>" for t in doc }
+	for sp in doc.noun_chunks :
+		if sp.end - sp.start > 1 : 
+			dic[sp.start] = "<u>" + dic[sp.start]
+			dic[sp.end-1] = dic[sp.end-1] + "</u>"
+	return [{"html": "<h1>"  + "".join([ v for v in dic.values()]) + "</h1>" }]
 
 @app.get('/spacy/toks', tags=["spacy"])
 def spacy_toks(text:str='The boy is happy. The quick fox jumped over the lazy dog.',chunks:bool=False, sino:str='sino', native:str='dic'): 
@@ -40,16 +75,6 @@ def spacy_toks(text:str='The boy is happy. The quick fox jumped over the lazy do
 		[ dic[ sp.end - 1 ]['chunks'].append( {'lempos': doc[sp.end - 1].lemma_ + "_NOUN", "type":"NP", "chunk":sp.text.lower() } ) for sp in doc.noun_chunks]   ## start/end ? 
 	return [ v for v in dic.values()]  # colored VERB html
 
-@app.get('/spacy/dsk', tags=["spacy"])
-def dsk(text:str='The boy is happy. The quick fox jumped over the lazy dog.'):
-	res = requests.post("http://gpu120.wrask.com:8180/gecdsk", json={"essay_or_snts":text}).json()
-	snts = [ dict( mkf.get("meta",{}), **{"feedback": [ v for cate, v in mkf.get('feedback',{}).items() ] } ) for mkf in res.get('snt',[])]
-	return {
-	#"feedback": [v for mkf in res.get('snt',[]) for cate, v in mkf.get('feedback',{}).items()], 
-	"snt": snts, 
-	"info": res.get('info',{}), 
-	}
-
 @app.get("/spacy/terms", tags=["spacy"])
 def nlp_terms(text:str="The quick fox jumped over the lazy dog. The justice delayed is justice denied."):
 	''' for sqlite indexing, 2022.3.4 '''
@@ -69,11 +94,23 @@ def nlp_sntbr(text:str="The quick fox jumped over the lazy dog. The justice dela
 	'''  '''
 	return spacy.sntbr(text, trim) 
 
-@app.post("/spacy/wordidf", tags=["spacy"])
-def nlp_wordidf(words:list=["niche","dilemma","consider","consider**"], default_idf:float=0):
+@app.get("/spacy/wordidf", tags=["spacy"])
+def nlp_wordidf(snt:str="The quick fox jumped over the lazy dog.", topk:int=3):
 	'''  '''
 	from dic.word_idf import word_idf 
-	return  { w: word_idf.get(w, default_idf) for w in words}
+	from collections import Counter
+	doc = spacy.nlp(snt)
+	si  = Counter()
+	[  si.update({t.text.lower() : word_idf.get(t.text.lower(), 0)}) for t in doc ]
+	return [{"word":w, "idf":idf} for w , idf in si.most_common(topk) if idf > 0  ]
+
+@app.get("/spacy/ecdic", tags=["spacy"])
+def nlp_ecdic(snt:str="The quick fox jumped over the lazy dog."):
+	'''  '''
+	from dic.ecdic import ecdic
+	doc = spacy.nlp(snt)
+	return [  { "word": t.lemma_, "trans": ecdic[t.lemma_]} for t in doc if not t.is_stop and t.lemma_ in ecdic ]
 
 if __name__ == "__main__":  #uvicorn.run(app, host='0.0.0.0', port=19200)
-	print (spacy_trp())	
\ No newline at end of file
+	#print (spacy_tok(morph=True))	
+	print ( nlp_ecdic()) 
\ No newline at end of file
