@@ -1,7 +1,6 @@
 # 2022.6.30 cp from uvicorn corpusly-19200:app --host 0.0.0.0 --port 19200 --reload
 from uvirun import *
 from util import likelihood
-#app = globals().get('app', fastapi.FastAPI())
 
 @app.post('/util/dualarr_keyness')
 def dualarr_keyness(src:dict={"one":2, "two":12}, tgt:dict={"three":3, "one":1}, sum1:float=None, sum2:float=None, threshold:float=0.0, leftonly:bool=False): 
@@ -17,4 +16,4 @@ def dualarr_keyness(src:dict={"one":2, "two":12}, tgt:dict={"three":3, "one":1},
 
 if __name__ == "__main__":  
 	print (dualarr_keyness())
-	#uvicorn.run(app, host='0.0.0.0', port=19200)
\ No newline at end of file
+	uvicorn.run(app, host='0.0.0.0', port=80)
\ No newline at end of file
